---
name: Bug Report
about: Let us know that something isn't working properly
labels: "Type: Bug"
---
Try to include:

- Code Sample, a copy-pastable example if possible
- A ["Minimal, Complete and Verifiable Example"](http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports)
  will make it much easier for maintainers to help you

```python
# Your code here

```

- Problem description: this should explain **why** the current behavior is a problem and why
  the expected output is a better solution.
- Expected output
- Which platform (Linux, Windows, Mac, etc.)
- Versions. Include the output of:
  - `python --version`
  - `python -c 'import metpy; print(metpy.__version__)'
